@@ -1,6 +1,6 @@
 package Catalyst::Example::InstantCRUD;
 
-use version; $VERSION = qv('0.0.3');
+use version; $VERSION = qv('0.0.4');
 
 use warnings;
 use strict;
@@ -20,7 +20,7 @@ Catalyst::Example::InstantCRUD
 
 =head1 VERSION
 
-This document describes Catalyst::Example::InstantCRUD version 0.0.1
+This document describes Catalyst::Example::InstantCRUD version 0.0.4
 
 
 =head1 SYNOPSIS
@@ -54,13 +54,16 @@ Template::Toolkit for View.
 =head1 CUSTOMISATION AND EXTENDING
 
 The first place for customisations are the Template Toolkit templates
-and the CSS file. To customize the templates copy them from the subdirectory templates of the directory where the Catalyst::Controller::PagingAndSort
-was installed to the "root" directory in the generated application and modify
-them.
-
+and the CSS file.
 The CSS file used by the application is root/static/pagingandsort.css.
+To customize the templates copy them from the subdirectory templates of the
+directory where the Catalyst::Controller::PagingAndSort
+was installed to the "root" directory in the generated application and 
+modify them.
 
-The generated controller is a subclass of Catalyst::Controller::PagingAndSort.
+The generated controller is a subclass of Catalyst::Controller::PagingAndSort. It's edit_columns method returns a hash describing all editable columns, 
+the constraints are then used to verify values in submited forms.  It should
+be modified to adjust the constraints to local requirements.
 You can use the standard OO technique of overriding the documented methods
 to customize and extend it.
 
